==> scTensor_1.0.3.tar.gz: scTensor/inst/doc/scTensor_1_Data_format_ID_Conversion.R <==
## ----scTensor with NCBI Gene ID, eval=FALSE--------------------------------
#  library("scTensor")
#  library("LRBase.XXX.eg.db") # e.g. LRBase.Hsa.eg.db
#  # Input matrix
#  input <- ...
#  sce <- SingleCellExperiment(assays=list(counts = input))
#  # Color vector
#  color <- ...
#  # Celltype vector
#  label <- ...
#  cellCellSetting(sce, LRBase.XXX.eg.db, color, label)

## ----Seurat, eval=FALSE----------------------------------------------------
#  suppressPackageStartupMessages(library("Seurat"))
#  
#  # Load the PBMC dataset
#  pbmc.data <- Read10X(data.dir = "filtered_gene_bc_matrices/hg19/")
#  
#  # Initialize the Seurat object with the raw (non-normalized data).
#  pbmc <- CreateSeuratObject(counts = pbmc.data,
#    project = "pbmc3k", min.cells = 3, min.features = 200)

## ----Ensembl with Organism DB, echo=TRUE-----------------------------------
suppressPackageStartupMessages(library("scTensor"))
suppressPackageStartupMessages(library("Homo.sapiens"))

# 1. Input matrix
input <- matrix(1:20, nrow=4, ncol=5)
# 2. Gene identifier in each row
rowID <- c("ENSG00000204531", "ENSG00000181449",
  "ENSG00000136997", "ENSG00000136826")
# 3. Corresponding table
LefttoRight <- select(Homo.sapiens,
  column=c("ENSEMBL", "ENTREZID"),
  keytype="ENSEMBL", keys=rowID)
# ID conversion
(input <- convertToNCBIGeneID(input, rowID, LefttoRight))

## ----Ensembl with biomaRt, echo=TRUE---------------------------------------
suppressPackageStartupMessages(library("biomaRt"))

# 1. Input matrix
input <- matrix(1:20, nrow=4, ncol=5)
# 3. Corresponding table
hg <- useMart("ensembl",
            dataset="hsapiens_gene_ensembl",
            host="asia.ensembl.org")
LefttoRight <- getBM(attributes=c("ensembl_gene_id", "entrezgene"),
  filters="ensembl_gene_id", values=rowID, mart=hg)
(input <- convertToNCBIGeneID(input, rowID, LefttoRight))

## ----Gene Symbol with Organism DB, echo=TRUE-------------------------------
# 1. Input matrix
input <- matrix(1:20, nrow=4, ncol=5)
# 2. Gene identifier in each row
rowID <- c("POU5F1", "SOX2", "MYC", "KLF4")
# 3. Corresponding table
LefttoRight <- select(Homo.sapiens,
  column=c("SYMBOL", "ENTREZID"),
  keytype="SYMBOL", keys=rowID)
# ID conversion
(input <- convertToNCBIGeneID(input, rowID, LefttoRight))

## ----Gene Symbol with biomaRt, echo=TRUE-----------------------------------
# 1. Input matrix
input <- matrix(1:20, nrow=4, ncol=5)
# 3. Corresponding table
LefttoRight <- getBM(attributes=c("hgnc_symbol", "entrezgene"),
  filters="hgnc_symbol", values=rowID, mart=hg)
(input <- convertToNCBIGeneID(input, rowID, LefttoRight))

## ----sessionInfo, echo=FALSE-----------------------------------------------
sessionInfo()

==> scTensor_1.0.7.tar.gz: scTensor/inst/doc/scTensor_1_Data_format_ID_Conversion.R <==
## ----scTensor with NCBI Gene ID, eval=FALSE--------------------------------
#  library("scTensor")
#  library("LRBase.XXX.eg.db") # e.g. LRBase.Hsa.eg.db
#  # Input matrix
#  input <- ...
#  sce <- SingleCellExperiment(assays=list(counts = input))
#  # Color vector
#  color <- ...
#  # Celltype vector
#  label <- ...
#  cellCellSetting(sce, LRBase.XXX.eg.db, color, label)

## ----Seurat, eval=FALSE----------------------------------------------------
#  suppressPackageStartupMessages(library("Seurat"))
#  
#  # Load the PBMC dataset
#  pbmc.data <- Read10X(data.dir = "filtered_gene_bc_matrices/hg19/")
#  
#  # Initialize the Seurat object with the raw (non-normalized data).
#  pbmc <- CreateSeuratObject(counts = pbmc.data,
#    project = "pbmc3k", min.cells = 3, min.features = 200)

## ----Ensembl with Organism DB, echo=TRUE-----------------------------------
suppressPackageStartupMessages(library("scTensor"))
suppressPackageStartupMessages(library("Homo.sapiens"))

# 1. Input matrix
input <- matrix(1:20, nrow=4, ncol=5)
# 2. Gene identifier in each row
rowID <- c("ENSG00000204531", "ENSG00000181449",
  "ENSG00000136997", "ENSG00000136826")
# 3. Corresponding table
LefttoRight <- select(Homo.sapiens,
  column=c("ENSEMBL", "ENTREZID"),
  keytype="ENSEMBL", keys=rowID)
# ID conversion
(input <- convertToNCBIGeneID(input, rowID, LefttoRight))

## ----Ensembl with AnnotationHub, echo=TRUE---------------------------------
suppressPackageStartupMessages(library("AnnotationHub"))

# 1. Input matrix
input <- matrix(1:20, nrow=4, ncol=5)
# 3. Corresponding table
ah <- AnnotationHub()
# Database of Human
hg <- ah[["AH70572"]]
LefttoRight <- select(hg,
  column=c("ENSEMBL", "ENTREZID"),
  keytype="ENSEMBL", keys=rowID)
(input <- convertToNCBIGeneID(input, rowID, LefttoRight))

## ----Gene Symbol with Organism DB, echo=TRUE-------------------------------
# 1. Input matrix
input <- matrix(1:20, nrow=4, ncol=5)
# 2. Gene identifier in each row
rowID <- c("POU5F1", "SOX2", "MYC", "KLF4")
# 3. Corresponding table
LefttoRight <- select(Homo.sapiens,
  column=c("SYMBOL", "ENTREZID"),
  keytype="SYMBOL", keys=rowID)
# ID conversion
(input <- convertToNCBIGeneID(input, rowID, LefttoRight))

## ----Gene Symbol with AnnotationHub, echo=TRUE-----------------------------
# 1. Input matrix
input <- matrix(1:20, nrow=4, ncol=5)
# 3. Corresponding table
ah <- AnnotationHub()
# Database of Human
hg <- ah[["AH70572"]]
LefttoRight <- select(hg,
  column=c("SYMBOL", "ENTREZID"),
  keytype="SYMBOL", keys=rowID)
(input <- convertToNCBIGeneID(input, rowID, LefttoRight))

## ----sessionInfo, echo=FALSE-----------------------------------------------
sessionInfo()
